@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from mvvmQt.rewriteContorls import Widget, Window, Label
-from PyQt5.QtWidgets import QFrame, QPushButton, QGridLayout, QLayout, QHBoxLayout, QVBoxLayout, QLabel, QTabWidget\
+from PyQt5.QtWidgets import QWidget, QFrame, QPushButton, QGridLayout, QLayout, QHBoxLayout, QVBoxLayout, QLabel, QTabWidget\
     , QStatusBar, QButtonGroup, QAbstractButton, QRadioButton
 from mvvmQt.Observable import ObservableBase
 
@@ -31,6 +31,7 @@ class Element:
         self.name = name.lower()
         self.parent = parent
         self.qt = None
+        self.isVitrual = False #如果为虚拟元素，则会将其子元素加到上级元素的子元素列表中
         self.dom = dom
         self.childs = []
         self.attrs = []
@@ -45,7 +46,7 @@ class Element:
             'grid': [self.createGridLayout, self.afterCreateGridLayout],
             'hbox': [self.createBox, self.afterCreateBox],
             'vbox': [self.createBox, self.afterCreateBox],
-            'bbutton-group': [self.createButtonGroup, self.afterCreateButtonGroup],
+            'button-group': [self.createButtonGroup, self.afterCreateButtonGroup],
             'button': [self.createButton, self.bindAll],
             'radio': [self.createRadio, self.bindAll],
             'label': [self.createLabel, self.bindAll],
@@ -119,6 +120,13 @@ class Element:
         self.bindAttr()
         self.bindEvent()
 
+    def findParentWidget(self):
+        o = self
+        while 1:
+            if type(o.parent.qt) in [Widget, Window]:
+                return o.parent.qt
+            o = o.parent
+
     def createWindow(self):
         self.qt = Window()
 
@@ -176,7 +184,7 @@ class Element:
         for e in es:
             if isinstance(e[0], QLayout):
                 self.qt.addLayout(*e)
-            else:
+            elif isinstance(e[0], QWidget):
                 self.qt.addWidget(*e)
 
         if self.parent and self.parent.name in self.topWidget:
@@ -195,7 +203,7 @@ class Element:
                 params.append(int(c.attrsToDict['stretch']))
             if isinstance(c.qt, QLayout):
                 self.qt.addLayout(*params)
-            else:
+            elif isinstance(c.qt, QWidget):
                 if 'align' in c.attrsToDict.keys():
                     params.append(self.parser.ElementAlignConfig[c.attrsToDict['align']])
                 self.qt.addWidget(*params)
@@ -207,13 +215,27 @@ class Element:
 
     def createButtonGroup(self):
         self.qt = QButtonGroup()
+        self.isVitrual = True
 
     def afterCreateButtonGroup(self):
+        #循环所有后代元素，gid相同时则添加到组内
+        childs = self.childs
+        store = []
+        while 1:
+            store.extend(list(filter(lambda c: len(c.childs) == 0, childs)))
+            l = list(filter(lambda c: len(c.childs) > 0, childs))
+            childs = []
+            for c in l:
+                childs.extend(c.childs)
+            if len(childs) == 0:
+                break
+        print(store)
         id = 1
-        for c in self.childs:
-            if isinstance(c.qt, QAbstractButton):
+        for c in store:
+            if isinstance(c.qt, QAbstractButton) and 'gid' in c.attrsToDict.keys() and c.attrsToDict['gid'] == self.attrsToDict['gid']:
                 self.qt.addButton(c.qt, id)
                 id += 1
+        self.bindAll()
 
     def createButton(self):
         self.qt = QPushButton(self.dom.text())
@@ -221,6 +243,20 @@ class Element:
     def createRadio(self):
         self.qt = QRadioButton(self.dom.text())
 
+    # def afterCreateRadio(self):
+    #     d = self.attrsToDict
+    #     if 'group' in d.keys():
+    #         gk = d['group']
+    #         if gk not in self.parser.btnGroups.keys():
+    #             self.parser.btnGroups[gk] = {
+    #                 'vqt': QButtonGroup(),
+    #                 'id': 0
+    #             }
+    #         g = self.parser.btnGroups[gk]
+    #         g['id'] += 1
+    #         g['vqt'].addButton(self.qt, g['id'])
+    #     self.bindAll()
+
     def createLabel(self):
         self.qt = Label(self.dom.text())
 
