@@ -23,6 +23,7 @@ class Parser:
         self.obj = obj
         self.indexName = indexName
         self.elements = [] #元素列表
+        self.btnGroups = {} #按键组
         self.models = models
         self.events = events
 
@@ -83,6 +84,8 @@ class Parser:
                 events.append(c)
             elif type(c) is self.ElementObj:
                 childs.append(c)
+                if c.isVitrual:
+                    childs.extend(c.childs)
 
         e.childs = childs
         e.attrs = attrs
