@@ -93,6 +93,10 @@ common = {
     'enable': ['setEnabled', bool]
 }
 
+btn = {
+    'checked': ['setChecked', [int, bool]]
+}
+
 ElementAttr = {
     'widget': {
         **size,
@@ -113,9 +117,11 @@ ElementAttr = {
         'vspacing': ['setVerticalSpacing', int],
         'hspacing': ['setHorizontalSpacing', int]
     },
+    'button-group': {
+        'exclusive': ['setExclusive', [int, bool]]
+    },
     'button': {
-        **size,
-        **common,
+        **size, **common, **btn,
         'shortcut': ['setShortcut', str],
         'tooltip': ['setToolTip', str],
         'checkable': ['setCheckable', bool],
@@ -124,6 +130,9 @@ ElementAttr = {
         'repeatDelay': ['setAutoRepeatDelay', int],
         'repeatInterval': ['setAutoRepeatInterval', int]
     },
+    'radio': {
+        **common, **btn
+    },
     'label': {
         **size, **common,
         'cv': ['setTextOrPixmap', cvImg],
